@@ -65,8 +65,11 @@ class User(PermissionsMixin):
 
         return obj
 
+    def get_email(self):
+        return self.email or self.info.email
+
     def get_username(self):
-        return self.email
+        return self.get_email()
 
     def is_anonymous(self):
         return self.info is not None
@@ -75,10 +78,10 @@ class User(PermissionsMixin):
         return bool(self.info)
 
     def __str__(self):
-        return self.email
+        return self.get_email()
 
     def __unicode__(self):
-        return self.email
+        return self.get_email()
 
     class Meta:
         verbose_name = _('user')
