@@ -216,7 +216,12 @@ class Shop(Service):
         """
         return self._callapi("shop/reviews/submit", post=postObject)
 
-    def get_reviews(self, limit=None, offset=None, product_id=None):
+    def get_reviews(
+            self,
+            limit=None,
+            offset=None,
+            product_id=None,
+            after_id=None):
         """
         :rtype : Collection|list of Review
         """
@@ -225,7 +230,8 @@ class Shop(Service):
             get={
                 "limit": limit,
                 "offset": offset,
-                "product_id": product_id})
+                "product_id": product_id,
+                "after_id": after_id})
 
     def get_cash_salons_cities(self, country_id):
         """
