@@ -136,11 +136,12 @@ def submit_review(postObject):
     return get_apiclient().services.shop.submit_review(postObject)
 
 
-def get_reviews(limit=None, offset=None, product_id=None):
+def get_reviews(limit=None, offset=None, product_id=None, after_id=None):
     return get_apiclient().services.shop.get_reviews(
         limit=limit,
         offset=offset,
-        product_id=product_id)
+        product_id=product_id,
+        after_id=after_id)
 
 
 def get_cash_salons_cities(country_id):
